<?php

namespace Drupal\eptcore\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\eptcore\Plugin\Field\FieldWidget\EptSettingsDefaultWidget;

/**
 * Plugin implementation of the 'ept_settings_simple' widget.
 *
 * @FieldWidget(
 *   id = "ept_settings_simple",
 *   label = @Translation("EPT Simple settings"),
 *   field_types = {
 *     "eptsettings"
 *   }
 * )
 */
class EptSettingsSimpleWidget extends EptSettingsDefaultWidget {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $element = parent::formElement($items, $delta, $element, $form, $form_state);
    unset($element['eptsettings']['design_options']['box1']);
    unset($element['eptsettings']['design_options']['other_settings']['border_color']);
    unset($element['eptsettings']['design_options']['other_settings']['border_style']);
    unset($element['eptsettings']['design_options']['other_settings']['border_radius']);
    unset($element['eptsettings']['design_options']['other_settings']['background_color']);
    unset($element['eptsettings']['design_options']['other_settings']['background_media']);
    unset($element['eptsettings']['design_options']['other_settings']['background_image_style']);

    $element['eptsettings']['design_options']['other_settings']['spacing'] = [
      '#type' => 'select',
      '#title' => $this->t('Background Image Style'),
      '#options' => [
        'spacing-none' => $this->t('None'),
        'spacing-sm' => $this->t('Small'),
        'spacing-md' => $this->t('Medium'),
        'spacing-lg' => $this->t('Large'),
        'spacing-xl' => $this->t('Extra Large'),
        'spacing-xxl' => $this->t('Double Extra Large'),
      ],
      '#default_value' => $items[$delta]->eptsettings['design_options']['other_settings']['spacing'] ?? 'spacing-none',
    ];

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function massageFormValues(array $values, array $form, FormStateInterface $form_state) {
    foreach ($values as &$value) {
      $value += ['eptsettings' => []];
    }

    return $values;
  }

}
